==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/da-DK/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Denne bruger kan logge ind',
    'activated_disabled_help_text' => 'Du kan ikke redigere rettigheder for din egen konto.',
    'assets_user'       => 'Aktiver tildelt :navn',
    'bulk_update_warn'	=> 'Du er ved at redigere egenskaberne for: user_count-brugere. Bemærk, at du ikke kan ændre dine egne brugerattributter ved hjælp af denne formular, og skal foretage ændringer til din egen bruger individuelt.',
    'bulk_update_help'	=> 'Denne formular giver dig mulighed for at opdatere flere brugere på én gang. Udfyld kun de felter, du skal ændre. Alle felter, der er tomt, forbliver uændrede.',
    'current_assets'    => 'Aktier tjekket ud for denne bruger',
    'clone'             => 'Klon bruger',
    'contact_user'      => 'Kontakt :navn',
    'edit'              => 'Redigér bruger',
    'filetype_info'     => 'Tilladte filtyper er png, gif, jpg, jpeg, doc, docx, pdf, txt, zip og rar.',
    'history_user'      => 'Historie for: navn',
    'info'				=> 'Information',
    'restore_user'		=> 'Klik her for at gendanne dem.',
    'last_login'        => 'Sidste Login',
    'ldap_config_text'  => 'LDAP-konfigurationsindstillinger kan findes Admin> Indstillinger. Den (valgfrie) valgte placering vil blive indstillet for alle importerede brugere.',
    'print_assigned'    => 'Udskriv alle tildelte',
    'email_assigned'    => 'E-mail liste over alle tildelt',
    'user_notified'     => 'Brugeren er blevet sendt en liste over deres aktuelt tildelte elementer.',
    'auto_assign_label' => 'Inkludér denne bruger ved automatisk tildeling af kvalificerede licenser',
    'auto_assign_help'  => 'Spring denne bruger over i auto-tildeling af licenser',
    'software_user'     => 'Software Checket ud til: navn',
    'send_email_help'   => 'Du skal angive en e-mail-adresse for denne bruger for at sende dem legitimationsoplysninger. E-mailing af legitimationsoplysninger kan kun gøres ved brugeroprettelse. Adgangskoder gemmes i en envejs hash og kan ikke hentes når de er gemt.',
    'view_user'         => 'Se bruger :navn',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dine nuværende administratorindstillinger tillader selektiv håndhævelse af tofaktors godkendelse.',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Bruger kan ikke logge ind',
    'user_activated'  => 'Bruger kan logge ind',
    'activation_status_warning' => 'Ændr ikke aktiveringsstatus',
    'group_memberships_helpblock' => 'Kun superadmins kan redigere gruppemedlemskaber.',
    'superadmin_permission_warning' => 'Kun superadmins kan give en bruger superadmin adgang.',
    'admin_permission_warning' => 'Kun brugere med administratorrettigheder eller større kan give en brugeradministrator adgang.',
    'remove_group_memberships' => 'Fjern Gruppemedlemskaber',
    'warning_deletion_information' => 'Du er ved at tjekke alle elementer fra :count bruger(e) nedenfor. Super admin navne er fremhævet med rødt.',
    'update_user_assets_status' => 'Opdater alle aktiver for disse brugere til denne status',
    'checkin_user_properties' => 'Check in all properties associated with these users (Automatic Copy)',
    'remote_label'   => 'Dette er en fjernbruger',
    'remote'   => 'Fjernbetjening',
    'remote_help' => 'Dette kan være nyttigt, hvis du har brug for at filtrere af fjernbrugere, der aldrig eller sjældent kommer ind på dine fysiske steder.',
    'not_remote_label' => 'Dette er ikke en fjernbruger',
    'vip_label' => 'VIP bruger',
    'vip_help' => 'Dette kan være nyttigt til at markere vigtige personer i din org hvis du gerne vil håndtere dem på særlige måder.',
    'create_user' => 'Opret en bruger',
    'create_user_page_explanation' => 'Dette er de kontooplysninger, du vil bruge til at få adgang til webstedet for første gang.',
    'email_credentials' => 'Email legitimationsoplysninger',
    'email_credentials_text' => 'E-mail mine legitimationsoplysninger til e-mail-adressen ovenfor',
    'next_save_user' => 'Næste: Gem Bruger',
    'all_assigned_list_generation' => 'Genereret den:',
    'email_user_creds_on_create' => 'Email denne bruger deres legitimationsoplysninger?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/da-DK/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Denne bruger kan logge ind',
    'activated_disabled_help_text' => 'Du kan ikke redigere rettigheder for din egen konto.',
    'assets_user'       => 'Aktiver tildelt :navn',
    'bulk_update_warn'	=> 'Du er ved at redigere egenskaberne for: user_count-brugere. Bemærk, at du ikke kan ændre dine egne brugerattributter ved hjælp af denne formular, og skal foretage ændringer til din egen bruger individuelt.',
    'bulk_update_help'	=> 'Denne formular giver dig mulighed for at opdatere flere brugere på én gang. Udfyld kun de felter, du skal ændre. Alle felter, der er tomt, forbliver uændrede.',
    'current_assets'    => 'Aktier tjekket ud for denne bruger',
    'clone'             => 'Klon bruger',
    'contact_user'      => 'Kontakt :navn',
    'edit'              => 'Redigér bruger',
    'filetype_info'     => 'Tilladte filtyper er png, gif, jpg, jpeg, doc, docx, pdf, txt, zip og rar.',
    'history_user'      => 'Historie for: navn',
    'info'				=> 'Information',
    'restore_user'		=> 'Klik her for at gendanne dem.',
    'last_login'        => 'Sidste Login',
    'ldap_config_text'  => 'LDAP-konfigurationsindstillinger kan findes Admin> Indstillinger. Den (valgfrie) valgte placering vil blive indstillet for alle importerede brugere.',
    'print_assigned'    => 'Udskriv alle tildelte',
    'email_assigned'    => 'E-mail liste over alle tildelt',
    'user_notified'     => 'Brugeren er blevet sendt en liste over deres aktuelt tildelte elementer.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inkludér denne bruger ved automatisk tildeling af kvalificerede licenser',
    'auto_assign_help'  => 'Spring denne bruger over i auto-tildeling af licenser',
    'software_user'     => 'Software Checket ud til: navn',
    'send_email_help'   => 'Du skal angive en e-mail-adresse for denne bruger for at sende dem legitimationsoplysninger. E-mailing af legitimationsoplysninger kan kun gøres ved brugeroprettelse. Adgangskoder gemmes i en envejs hash og kan ikke hentes når de er gemt.',
    'view_user'         => 'Se bruger :navn',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dine nuværende administratorindstillinger tillader selektiv håndhævelse af tofaktors godkendelse.',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Bruger kan ikke logge ind',
    'user_activated'  => 'Bruger kan logge ind',
    'activation_status_warning' => 'Ændr ikke aktiveringsstatus',
    'group_memberships_helpblock' => 'Kun superadmins kan redigere gruppemedlemskaber.',
    'superadmin_permission_warning' => 'Kun superadmins kan give en bruger superadmin adgang.',
    'admin_permission_warning' => 'Kun brugere med administratorrettigheder eller større kan give en brugeradministrator adgang.',
    'remove_group_memberships' => 'Fjern Gruppemedlemskaber',
    'warning_deletion_information' => 'Du er ved at tjekke alle elementer fra :count bruger(e) nedenfor. Super admin navne er fremhævet med rødt.',
    'update_user_assets_status' => 'Opdater alle aktiver for disse brugere til denne status',
    'checkin_user_properties' => 'Check in all properties associated with these users (Automatic Copy)',
    'remote_label'   => 'Dette er en fjernbruger',
    'remote'   => 'Fjernbetjening',
    'remote_help' => 'Dette kan være nyttigt, hvis du har brug for at filtrere af fjernbrugere, der aldrig eller sjældent kommer ind på dine fysiske steder.',
    'not_remote_label' => 'Dette er ikke en fjernbruger',
    'vip_label' => 'VIP bruger',
    'vip_help' => 'Dette kan være nyttigt til at markere vigtige personer i din org hvis du gerne vil håndtere dem på særlige måder.',
    'create_user' => 'Opret en bruger',
    'create_user_page_explanation' => 'Dette er de kontooplysninger, du vil bruge til at få adgang til webstedet for første gang.',
    'email_credentials' => 'Email legitimationsoplysninger',
    'email_credentials_text' => 'E-mail mine legitimationsoplysninger til e-mail-adressen ovenfor',
    'next_save_user' => 'Næste: Gem Bruger',
    'all_assigned_list_generation' => 'Genereret den:',
    'email_user_creds_on_create' => 'Email denne bruger deres legitimationsoplysninger?',
];
